@@ -8,6 +8,7 @@ from botx.clients.methods.v3.command.command_result import CommandResult
 from botx.clients.types.message_payload import ResultPayload
 from botx.clients.types.options import ResultOptions
 from botx.models.messages.sending.credentials import SendingCredentials
+from botx.models.messages.sending.options import ResultPayloadOptions
 from botx.models.messages.sending.payload import MessagePayload
 
 
@@ -38,11 +39,14 @@ class CommandRequestsMixin:
                     bubble=payload.markup.bubbles,
                     keyboard=payload.markup.keyboard,
                     mentions=payload.options.mentions,
+                    opts=ResultPayloadOptions(
+                        silent_response=payload.options.silent_response,
+                    ),
                 ),
                 recipients=payload.options.recipients,
                 file=payload.file,
                 opts=ResultOptions(
-                    silent_response=payload.options.silent_response,
+                    stealth_mode=payload.options.stealth_mode,
                     notification_opts=payload.options.notifications,
                 ),
             ),
