@@ -1,7 +1,6 @@
 """Definition of middleware that will generate BotX API errors depending from flag."""
 from typing import Any, Callable, Tuple, Type, cast
 
-import httpx
 from molten import BaseApp, Request, Response, Route, Settings
 from pydantic import BaseModel
 
@@ -10,7 +9,9 @@ from botx.testing.botx_mock.wsgi.responses import PydanticResponse
 
 
 def _get_error_from_request(
-    request: Request, app: BaseApp, settings: Settings,
+    request: Request,
+    app: BaseApp,
+    settings: Settings,
 ) -> Tuple[Type[BotXMethod], Tuple[int, BaseModel]]:
     match = app.router.match(request.method, request.path)
     route, _ = cast(Tuple[Route, Any], match)
@@ -19,7 +20,9 @@ def _get_error_from_request(
 
 
 def should_generate_error_response(
-    request: Request, app: BaseApp, settings: Settings,
+    request: Request,
+    app: BaseApp,
+    settings: Settings,
 ) -> bool:
     """Check if mocked API should generate error response.
 
@@ -36,7 +39,9 @@ def should_generate_error_response(
 
 
 def generate_error_response(
-    request: Request, app: BaseApp, settings: Settings,
+    request: Request,
+    app: BaseApp,
+    settings: Settings,
 ) -> Response:
     """Generate error response for mocked BotX API.
 
@@ -53,11 +58,12 @@ def generate_error_response(
 
     return PydanticResponse(
         APIErrorResponse[BaseModel](
-            errors=["error from mock"], reason="asked_for_error", error_data=error_data,
-        ),
-        status_code="{0} {1}".format(
-            status_code, httpx.codes.get_reason_phrase(status_code),
+            errors=["error from mock"],
+            reason="asked_for_error",
+            error_data=error_data,
         ),
+        # TODO: Drop unnecessary description.
+        status_code="{0} <status code description>".format(status_code),
     )
 
 
